@@ -4,8 +4,8 @@ SPDX-FileCopyrightText: 2002-2004 Otto Bruggeman <otto.bruggeman@home.nl>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DIFFPARSER_H
-#define DIFFPARSER_H
+#ifndef KOMPAREDIFF2_DIFFPARSER_H
+#define KOMPAREDIFF2_DIFFPARSER_H
 
 #include "parserbase.h"
 
