@@ -5,8 +5,8 @@ SPDX-FileCopyrightText: 2001-2003 John Firebaugh <jfirebaugh@kde.org>
 SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DIFFSETTINGS_H
-#define DIFFSETTINGS_H
+#ifndef KOMPAREDIFF2_DIFFSETTINGS_H
+#define KOMPAREDIFF2_DIFFSETTINGS_H
 
 #include <QStringList>
 
